@@ -1,5 +1,6 @@
 from pathfind.finder.finder import BaseFinder
 from pathfind.finder.queue import LifoFinderQueue
+from pathfind.graph.edge import INFINITY
 from pathfind.graph.node import Node
 
 
@@ -10,6 +11,8 @@ class DepthFirstSearch(BaseFinder):
     def check_neighbors(self, current: Node):
         for neighbor in self.successors(current):
             n = neighbor.node
+            if neighbor.weight == INFINITY:
+                continue
             if not self.is_visited(n):
                 self.set_g(n)
                 self.queue.put(n)
