@@ -1,5 +1,7 @@
+from pathfind.finder import tool
 from pathfind.finder.finder import BaseFinder
 from pathfind.finder.queue import PriorityFinderQueue
+from pathfind.graph.edge import INFINITY
 from pathfind.graph.graph import Node
 
 
@@ -11,16 +13,14 @@ class GreedyBestFirst(BaseFinder):
     def check_neighbors(self, current: Node):
         for neighbor in self.successors(current):
             n = neighbor.node
+            if neighbor.weight == INFINITY:
+                continue
             if n.name not in self.came_from:
                 self.queue.put(n, self.heuristic(n))
                 self.came_from[n.name] = current
 
     def heuristic(self, node: Node) -> float:
-        if self.distance_method == "manhattan":
-            return self.end.manhattan_distance(node)
-        elif self.distance_method == "euclidean":
-            return self.end.euclidean_distance(node)
-        return self.end.manhattan_distance(node)
+        return tool.distance(node, self.end, self.distance_method)
 
 
 class Greedy(GreedyBestFirst):
